# ldc-openai
[llm-dataset-converter](https://github.com/waikato-datamining/llm-dataset-converter) 
plugins for [OpenAI](https://openai.com/).


## Installation

```bash
pip install git+https://github.com/waikato-llm/llm-dataset-converter.git
pip install git+https://github.com/waikato-llm/ldc-openai.git
```

## Plugins

See [here](plugins/README.md) for an overview of all plugins.
